execline: the execline-shell script
Keywords: execline script execline-shell

execline
Software
skarnet.org

# The `execline-shell` script

`execline-shell` executes `$HOME/.execline-shell` with the arguments it is given.

## Interface

         /etc/execline-shell

- `execline-shell` transforms itself into `${HOME}/.execline-shell $@`.
- `${HOME}/.execline-shell` must be readable and executable by the user. It must exec into an interactive shell with `$@` as its argument.

## Notes

- `execline-shell` is meant to be used as the `SHELL` environment variable value. It allows one to specify his favourite shell and shell configuration in any language, since the `${HOME}/.execline-shell` file can be any executable program. `${HOME}/.execline-shell` can be seen as a portable `.whateverrc` file.
- As an administrator-modifiable configuration file, `execline-shell` provided in execline's `etc/` subdirectory, and should be copied by the administrator to `/etc`.